@@ -64,6 +64,7 @@ class Browser(webdriver.Chrome):
 
     def __init__(self, hide=True, clean=True, pictures=False, **kwargs):
 
+        #super(webdriver.Chrome, self).__init__()
         #setting up controls
         if clean not in [True,False]:
             self.__clean = False
@@ -96,7 +97,7 @@ class Browser(webdriver.Chrome):
             Browser = webdriver.Chrome(service_args=['--silent'], desired_capabilities=self.__caps)
 
         # noinspection SpellCheckingInspection
-        Browser = webdriver.Chrome(options=self.__options, service_args=['--silent'], desired_capabilities=self.__caps)
+        #Browser = webdriver.Chrome(options=self.__options, service_args=['--silent'], desired_capabilities=self.__caps)
         Browser.header_overrides = Header
         self.session_id = Browser.session_id
         self.command_executor = Browser.command_executor
